# Changelog

<!--next-version-placeholder-->

## v0.2.0 (2022-07-11)
### Feature
* Schema_as_flat_list - add include_datatype ([`68d4c71`](https://github.com/avolok/spalah/commit/68d4c71e99156c00ffe99b20d1d2cb90945b30a2))

## v0.1.0 (2022-07-10)
### Feature
* Initial code commit ([`844616f`](https://github.com/avolok/spalah/commit/844616ffb6ab89ab31c97644d74943bf9c15070e))

### Fix
* Downgrade of version to fix psr release ([#2](https://github.com/avolok/spalah/issues/2)) ([`e5b470c`](https://github.com/avolok/spalah/commit/e5b470c1379e285c0603fed5d3dcd489314469e1))

## v0.1.0 (2022-07-09)
### Feature
* Initial commit
